// Main.cpp

#include <iostream>

#include <Kinect.h>

IKinectSensor *kinect_sensor = nullptr;

void ShowCapabilities(const DWORD cap)
{
  std::cout << "*** Kinect Capabilities: " << std::endl;
  std::cout << "Vision: "
            << ((cap & KinectCapabilities_Vision) ? "yes" : "no")
            << std::endl;
  std::cout << "Audio: "
            << ((cap & KinectCapabilities_Audio) ? "yes" : "no")
            << std::endl;
  std::cout << "Face: "
            << ((cap & KinectCapabilities_Face) ? "yes" : "no")
            << std::endl;
  std::cout << "Expressions: "
            << ((cap & KinectCapabilities_Expressions) ? "yes" : "no")
            << std::endl;
  std::cout << "Gamechat: "
            << ((cap & KinectCapabilities_Gamechat) ? "yes" : "no")
            << std::endl;
}

HRESULT InitializeDefaultSensor(void)
{
    HRESULT hr;

    if (kinect_sensor) {
      std::cerr << "InitializeDefaultSensor(): already initialized"
                << std::endl;
    }

    hr = GetDefaultKinectSensor(&kinect_sensor);
    if (FAILED(hr)) {
      std::cerr << "GetDefaultKinectSensor() failed" << std::endl;
      return hr;
    }

    hr = kinect_sensor->Open();
    if (FAILED(hr)) {
      std::cerr << "IKinectSensor::Open() failed" << std::endl;
      return hr;
    }

    DWORD capabilities;
    hr = kinect_sensor->get_KinectCapabilities(&capabilities);
    if (FAILED(hr)) {
      std::cerr << "IKinectSensor::get_KinectCapabilities() failed"
                << std::endl;
      return hr;
    }
    ShowCapabilities(capabilities);

    return hr;
}

void CloseSensor(void)
{
  if (kinect_sensor) {
    kinect_sensor->Close();
  }
  kinect_sensor = nullptr;
}

int main(int argc, char **argv)
{
  InitializeDefaultSensor();

  CloseSensor();
 
  return 0;
}
